"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.lockbox.v1.secret_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PayloadEntryChange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    TEXT_VALUE_FIELD_NUMBER: builtins.int
    BINARY_VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    """Non-confidential key of the entry."""
    text_value: builtins.str
    """Use the field to set a text value."""
    binary_value: builtins.bytes
    """Use the field to set a binary value."""
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        text_value: builtins.str = ...,
        binary_value: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["binary_value", b"binary_value", "text_value", b"text_value", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["binary_value", b"binary_value", "key", b"key", "text_value", b"text_value", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["value", b"value"]) -> typing.Literal["text_value", "binary_value"] | None: ...

global___PayloadEntryChange = PayloadEntryChange

@typing.final
class GetSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret to return.

    To get a secret ID make a [List] request.
    """
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["secret_id", b"secret_id"]) -> None: ...

global___GetSecretRequest = GetSecretRequest

@typing.final
class ListSecretsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list secrets in."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListSecretsRequest.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListSecretsRequest.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListSecretsRequest = ListSecretsRequest

@typing.final
class ListSecretsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRETS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number
    of results is greater than the specified [ListSecretsRequest.page_size], use
    the `next_page_token` as the value for the [ListSecretsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    `next_page_token` to continue paging through the results.
    """
    @property
    def secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.lockbox.v1.secret_pb2.Secret]:
        """List of secrets in the specified folder."""

    def __init__(
        self,
        *,
        secrets: collections.abc.Iterable[yandex.cloud.lockbox.v1.secret_pb2.Secret] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "secrets", b"secrets"]) -> None: ...

global___ListSecretsResponse = ListSecretsResponse

@typing.final
class CreateSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    VERSION_DESCRIPTION_FIELD_NUMBER: builtins.int
    VERSION_PAYLOAD_ENTRIES_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    PASSWORD_PAYLOAD_SPECIFICATION_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a secret in."""
    name: builtins.str
    """Name of the secret."""
    description: builtins.str
    """Description of the secret."""
    kms_key_id: builtins.str
    """Optional ID of the KMS key will be used to encrypt and decrypt the secret."""
    version_description: builtins.str
    """Description of the first version."""
    deletion_protection: builtins.bool
    """Flag that inhibits deletion of the secret."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the secret as `key:value` pairs. Maximum 64 per key.
        For example, `"project": "mvp"` or `"source": "dictionary"`.
        """

    @property
    def version_payload_entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PayloadEntryChange]:
        """Payload entries added to the first version."""

    @property
    def password_payload_specification(self) -> yandex.cloud.lockbox.v1.secret_pb2.PasswordPayloadSpecification: ...
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        kms_key_id: builtins.str = ...,
        version_description: builtins.str = ...,
        version_payload_entries: collections.abc.Iterable[global___PayloadEntryChange] | None = ...,
        deletion_protection: builtins.bool = ...,
        password_payload_specification: yandex.cloud.lockbox.v1.secret_pb2.PasswordPayloadSpecification | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["password_payload_specification", b"password_payload_specification", "payload_specification", b"payload_specification"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "kms_key_id", b"kms_key_id", "labels", b"labels", "name", b"name", "password_payload_specification", b"password_payload_specification", "payload_specification", b"payload_specification", "version_description", b"version_description", "version_payload_entries", b"version_payload_entries"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["payload_specification", b"payload_specification"]) -> typing.Literal["password_payload_specification"] | None: ...

global___CreateSecretRequest = CreateSecretRequest

@typing.final
class CreateSecretMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret being created."""
    version_id: builtins.str
    """ID of the current version of the secret being created."""
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["secret_id", b"secret_id", "version_id", b"version_id"]) -> None: ...

global___CreateSecretMetadata = CreateSecretMetadata

@typing.final
class UpdateSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    SECRET_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    PASSWORD_PAYLOAD_SPECIFICATION_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret to update."""
    name: builtins.str
    """New name of the secret."""
    description: builtins.str
    """New description of the secret."""
    deletion_protection: builtins.bool
    """Flag that inhibits deletion of the secret."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the secret are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the secret as `key:value` pairs. Maximum 64 per key."""

    @property
    def password_payload_specification(self) -> yandex.cloud.lockbox.v1.secret_pb2.PasswordPayloadSpecification: ...
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        password_payload_specification: yandex.cloud.lockbox.v1.secret_pb2.PasswordPayloadSpecification | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["password_payload_specification", b"password_payload_specification", "payload_specification", b"payload_specification", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["deletion_protection", b"deletion_protection", "description", b"description", "labels", b"labels", "name", b"name", "password_payload_specification", b"password_payload_specification", "payload_specification", b"payload_specification", "secret_id", b"secret_id", "update_mask", b"update_mask"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["payload_specification", b"payload_specification"]) -> typing.Literal["password_payload_specification"] | None: ...

global___UpdateSecretRequest = UpdateSecretRequest

@typing.final
class UpdateSecretMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret being updated."""
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["secret_id", b"secret_id"]) -> None: ...

global___UpdateSecretMetadata = UpdateSecretMetadata

@typing.final
class DeleteSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret to be deleted."""
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["secret_id", b"secret_id"]) -> None: ...

global___DeleteSecretRequest = DeleteSecretRequest

@typing.final
class DeleteSecretMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret being deleted."""
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["secret_id", b"secret_id"]) -> None: ...

global___DeleteSecretMetadata = DeleteSecretMetadata

@typing.final
class ActivateSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret to be activated."""
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["secret_id", b"secret_id"]) -> None: ...

global___ActivateSecretRequest = ActivateSecretRequest

@typing.final
class ActivateSecretMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret being activated."""
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["secret_id", b"secret_id"]) -> None: ...

global___ActivateSecretMetadata = ActivateSecretMetadata

@typing.final
class DeactivateSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret to be deactivated."""
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["secret_id", b"secret_id"]) -> None: ...

global___DeactivateSecretRequest = DeactivateSecretRequest

@typing.final
class DeactivateSecretMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret being deactivated."""
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["secret_id", b"secret_id"]) -> None: ...

global___DeactivateSecretMetadata = DeactivateSecretMetadata

@typing.final
class AddVersionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PAYLOAD_ENTRIES_FIELD_NUMBER: builtins.int
    BASE_VERSION_ID_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret."""
    description: builtins.str
    """Description of the version."""
    base_version_id: builtins.str
    """Optional base version id. Defaults to the current version if not specified"""
    @property
    def payload_entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PayloadEntryChange]:
        """Describe how payload entries of the base version change in the added version."""

    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
        description: builtins.str = ...,
        payload_entries: collections.abc.Iterable[global___PayloadEntryChange] | None = ...,
        base_version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["base_version_id", b"base_version_id", "description", b"description", "payload_entries", b"payload_entries", "secret_id", b"secret_id"]) -> None: ...

global___AddVersionRequest = AddVersionRequest

@typing.final
class AddVersionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret."""
    version_id: builtins.str
    """ID of the added version."""
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["secret_id", b"secret_id", "version_id", b"version_id"]) -> None: ...

global___AddVersionMetadata = AddVersionMetadata

@typing.final
class ListVersionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret to list versions for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListVersionsRequest.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListVersionsRequest.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "secret_id", b"secret_id"]) -> None: ...

global___ListVersionsRequest = ListVersionsRequest

@typing.final
class ListVersionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number
    of results is greater than the specified [ListVersionsRequest.page_size], use
    the `next_page_token` as the value for the [ListVersionsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    `next_page_token` to continue paging through the results.
    """
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.lockbox.v1.secret_pb2.Version]:
        """List of versions for the specified secret."""

    def __init__(
        self,
        *,
        versions: collections.abc.Iterable[yandex.cloud.lockbox.v1.secret_pb2.Version] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "versions", b"versions"]) -> None: ...

global___ListVersionsResponse = ListVersionsResponse

@typing.final
class ScheduleVersionDestructionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    PENDING_PERIOD_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret whose version should be scheduled for destruction."""
    version_id: builtins.str
    """ID of the version to be destroyed."""
    @property
    def pending_period(self) -> google.protobuf.duration_pb2.Duration:
        """Time interval between the version destruction request and actual destruction.
        Default value: 7 days.
        """

    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
        version_id: builtins.str = ...,
        pending_period: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pending_period", b"pending_period"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["pending_period", b"pending_period", "secret_id", b"secret_id", "version_id", b"version_id"]) -> None: ...

global___ScheduleVersionDestructionRequest = ScheduleVersionDestructionRequest

@typing.final
class ScheduleVersionDestructionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    DESTROY_AT_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret whose version is being scheduled for destruction."""
    version_id: builtins.str
    """ID of the version that is being scheduled for destruction."""
    @property
    def destroy_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Destruction timestamp."""

    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
        version_id: builtins.str = ...,
        destroy_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destroy_at", b"destroy_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destroy_at", b"destroy_at", "secret_id", b"secret_id", "version_id", b"version_id"]) -> None: ...

global___ScheduleVersionDestructionMetadata = ScheduleVersionDestructionMetadata

@typing.final
class CancelVersionDestructionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret to cancel a version's destruction for."""
    version_id: builtins.str
    """ID of the secret whose scheduled destruction should be cancelled."""
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["secret_id", b"secret_id", "version_id", b"version_id"]) -> None: ...

global___CancelVersionDestructionRequest = CancelVersionDestructionRequest

@typing.final
class CancelVersionDestructionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret whose version's destruction is being cancelled."""
    version_id: builtins.str
    """ID of the version whose scheduled destruction is being cancelled."""
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["secret_id", b"secret_id", "version_id", b"version_id"]) -> None: ...

global___CancelVersionDestructionMetadata = CancelVersionDestructionMetadata

@typing.final
class ListSecretOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """ID of the secret to get operations for."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `page_size`, the service returns a [ListSecretOperationsRequest.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListSecretOperationsRequest.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "secret_id", b"secret_id"]) -> None: ...

global___ListSecretOperationsRequest = ListSecretOperationsRequest

@typing.final
class ListSecretOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListSecretOperationsResponse.page_size], use the `next_page_token` as the value
    for the [ListSecretOperationsResponse.page_token] query parameter in the next list request.
    Each subsequent list request will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified secret."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListSecretOperationsResponse = ListSecretOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.containerregistry.v1.lifecycle_policy_pb2
import yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class LifecyclePolicyServiceStub:
    """A set of methods for managing Lifecycle policy resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.GetLifecyclePolicyRequest,
        yandex.cloud.containerregistry.v1.lifecycle_policy_pb2.LifecyclePolicy,
    ]
    """Returns the specified lifecycle policy.

    To get the list of all available lifecycle policies, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListLifecyclePoliciesRequest,
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListLifecyclePoliciesResponse,
    ]
    """Retrieves the list of lifecycle policies in the specified repository."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.CreateLifecyclePolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a lifecycle policy in the specified repository."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.UpdateLifecyclePolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified lifecycle policy."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.DeleteLifecyclePolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified lifecycle policy."""

    DryRun: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.DryRunLifecyclePolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a request of a dry run of the lifecycle policy."""

    GetDryRunResult: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.GetDryRunLifecyclePolicyResultRequest,
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.DryRunLifecyclePolicyResult,
    ]
    """Returns the dry run result of the specified lifecycle policy."""

    ListDryRunResults: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListDryRunLifecyclePolicyResultsRequest,
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListDryRunLifecyclePolicyResultsResponse,
    ]
    """Retrieves the list of the dry run results."""

    ListDryRunResultAffectedImages: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListDryRunLifecyclePolicyResultAffectedImagesRequest,
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListDryRunLifecyclePolicyResultAffectedImagesResponse,
    ]
    """Retrieves the list of the affected images."""

class LifecyclePolicyServiceAsyncStub:
    """A set of methods for managing Lifecycle policy resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.GetLifecyclePolicyRequest,
        yandex.cloud.containerregistry.v1.lifecycle_policy_pb2.LifecyclePolicy,
    ]
    """Returns the specified lifecycle policy.

    To get the list of all available lifecycle policies, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListLifecyclePoliciesRequest,
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListLifecyclePoliciesResponse,
    ]
    """Retrieves the list of lifecycle policies in the specified repository."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.CreateLifecyclePolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a lifecycle policy in the specified repository."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.UpdateLifecyclePolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified lifecycle policy."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.DeleteLifecyclePolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified lifecycle policy."""

    DryRun: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.DryRunLifecyclePolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a request of a dry run of the lifecycle policy."""

    GetDryRunResult: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.GetDryRunLifecyclePolicyResultRequest,
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.DryRunLifecyclePolicyResult,
    ]
    """Returns the dry run result of the specified lifecycle policy."""

    ListDryRunResults: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListDryRunLifecyclePolicyResultsRequest,
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListDryRunLifecyclePolicyResultsResponse,
    ]
    """Retrieves the list of the dry run results."""

    ListDryRunResultAffectedImages: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListDryRunLifecyclePolicyResultAffectedImagesRequest,
        yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListDryRunLifecyclePolicyResultAffectedImagesResponse,
    ]
    """Retrieves the list of the affected images."""

class LifecyclePolicyServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Lifecycle policy resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.GetLifecyclePolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.containerregistry.v1.lifecycle_policy_pb2.LifecyclePolicy, collections.abc.Awaitable[yandex.cloud.containerregistry.v1.lifecycle_policy_pb2.LifecyclePolicy]]:
        """Returns the specified lifecycle policy.

        To get the list of all available lifecycle policies, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListLifecyclePoliciesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListLifecyclePoliciesResponse, collections.abc.Awaitable[yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListLifecyclePoliciesResponse]]:
        """Retrieves the list of lifecycle policies in the specified repository."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.CreateLifecyclePolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a lifecycle policy in the specified repository."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.UpdateLifecyclePolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified lifecycle policy."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.DeleteLifecyclePolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified lifecycle policy."""

    @abc.abstractmethod
    def DryRun(
        self,
        request: yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.DryRunLifecyclePolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a request of a dry run of the lifecycle policy."""

    @abc.abstractmethod
    def GetDryRunResult(
        self,
        request: yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.GetDryRunLifecyclePolicyResultRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.DryRunLifecyclePolicyResult, collections.abc.Awaitable[yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.DryRunLifecyclePolicyResult]]:
        """Returns the dry run result of the specified lifecycle policy."""

    @abc.abstractmethod
    def ListDryRunResults(
        self,
        request: yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListDryRunLifecyclePolicyResultsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListDryRunLifecyclePolicyResultsResponse, collections.abc.Awaitable[yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListDryRunLifecyclePolicyResultsResponse]]:
        """Retrieves the list of the dry run results."""

    @abc.abstractmethod
    def ListDryRunResultAffectedImages(
        self,
        request: yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListDryRunLifecyclePolicyResultAffectedImagesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListDryRunLifecyclePolicyResultAffectedImagesResponse, collections.abc.Awaitable[yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2.ListDryRunLifecyclePolicyResultAffectedImagesResponse]]:
        """Retrieves the list of the affected images."""

def add_LifecyclePolicyServiceServicer_to_server(servicer: LifecyclePolicyServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AccessBindingAction:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AccessBindingActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AccessBindingAction.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ACCESS_BINDING_ACTION_UNSPECIFIED: _AccessBindingAction.ValueType  # 0
    ADD: _AccessBindingAction.ValueType  # 1
    """Addition of an access binding."""
    REMOVE: _AccessBindingAction.ValueType  # 2
    """Removal of an access binding."""

class AccessBindingAction(_AccessBindingAction, metaclass=_AccessBindingActionEnumTypeWrapper): ...

ACCESS_BINDING_ACTION_UNSPECIFIED: AccessBindingAction.ValueType  # 0
ADD: AccessBindingAction.ValueType  # 1
"""Addition of an access binding."""
REMOVE: AccessBindingAction.ValueType  # 2
"""Removal of an access binding."""
global___AccessBindingAction = AccessBindingAction

@typing.final
class Subject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the subject.

    It can contain one of the following values:
    * `allAuthenticatedUsers`: A special public group that represents anyone
       who is authenticated. It can be used only if the [type] is `system`.
    * `allUsers`: A special public group that represents anyone. No authentication is required.
       For example, you don't need to specify the IAM token in an API query.
       It can be used only if the [type] is `system`.
    * `group:organization:<id>:users`: A special system group that represents all members of organization
       with given <id>. It can be used only if the [type] is `system`.
    * `group:federation:<id>:users`: A special system group that represents all users of federation
       with given <id>. It can be used only if the [type] is `system`.
    * `<cloud generated id>`: An identifier that represents a user account.
       It can be used only if the [type] is `userAccount`, `federatedUser` or `serviceAccount`.
    """
    type: builtins.str
    """Type of the subject.

    It can contain one of the following values:
    * `userAccount`: An account on Yandex or Yandex Connect, added to Yandex Cloud.
    * `serviceAccount`: A service account. This type represents the [yandex.cloud.iam.v1.ServiceAccount] resource.
    * `federatedUser`: A federated account. This type represents a user from an identity federation, like Active Directory.
    * `system`: System group. This type represents several accounts with a common system identifier.

    For more information, see [Subject to which the role is assigned](/docs/iam/concepts/access-control/#subject).
    """
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "type", b"type"]) -> None: ...

global___Subject = Subject

@typing.final
class AccessBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_ID_FIELD_NUMBER: builtins.int
    SUBJECT_FIELD_NUMBER: builtins.int
    role_id: builtins.str
    """ID of the [yandex.cloud.iam.v1.Role] that is assigned to the [subject]."""
    @property
    def subject(self) -> global___Subject:
        """Identity for which access binding is being created.
        It can represent an account with a unique ID or several accounts with a system identifier.
        """

    def __init__(
        self,
        *,
        role_id: builtins.str = ...,
        subject: global___Subject | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["subject", b"subject"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["role_id", b"role_id", "subject", b"subject"]) -> None: ...

global___AccessBinding = AccessBinding

@typing.final
class ListAccessBindingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource to list access bindings for.

    To get the resource ID, use a corresponding List request.
    For example, use the [yandex.cloud.resourcemanager.v1.CloudService.List] request to get the Cloud resource ID.
    """
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than [page_size],
    the service returns a [ListAccessBindingsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set [page_token]
    to the [ListAccessBindingsResponse.next_page_token]
    returned by a previous list request to get the next page of results.
    """
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "resource_id", b"resource_id"]) -> None: ...

global___ListAccessBindingsRequest = ListAccessBindingsRequest

@typing.final
class ListAccessBindingsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_BINDINGS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListAccessBindingsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListAccessBindingsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def access_bindings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AccessBinding]:
        """List of access bindings for the specified resource."""

    def __init__(
        self,
        *,
        access_bindings: collections.abc.Iterable[global___AccessBinding] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["access_bindings", b"access_bindings", "next_page_token", b"next_page_token"]) -> None: ...

global___ListAccessBindingsResponse = ListAccessBindingsResponse

@typing.final
class SetAccessBindingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    ACCESS_BINDINGS_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource for which access bindings are being set.

    To get the resource ID, use a corresponding List request.
    """
    @property
    def access_bindings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AccessBinding]:
        """Access bindings to be set. For more information, see [Access Bindings](/docs/iam/concepts/access-control/#access-bindings)."""

    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
        access_bindings: collections.abc.Iterable[global___AccessBinding] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["access_bindings", b"access_bindings", "resource_id", b"resource_id"]) -> None: ...

global___SetAccessBindingsRequest = SetAccessBindingsRequest

@typing.final
class SetAccessBindingsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource for which access bindings are being set."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___SetAccessBindingsMetadata = SetAccessBindingsMetadata

@typing.final
class UpdateAccessBindingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    ACCESS_BINDING_DELTAS_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource for which access bindings are being updated."""
    @property
    def access_binding_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AccessBindingDelta]:
        """Updates to access bindings."""

    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
        access_binding_deltas: collections.abc.Iterable[global___AccessBindingDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["access_binding_deltas", b"access_binding_deltas", "resource_id", b"resource_id"]) -> None: ...

global___UpdateAccessBindingsRequest = UpdateAccessBindingsRequest

@typing.final
class UpdateAccessBindingsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource for which access bindings are being updated."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___UpdateAccessBindingsMetadata = UpdateAccessBindingsMetadata

@typing.final
class AccessBindingDelta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    ACCESS_BINDING_FIELD_NUMBER: builtins.int
    action: global___AccessBindingAction.ValueType
    """The action that is being performed on an access binding."""
    @property
    def access_binding(self) -> global___AccessBinding:
        """Access binding. For more information, see [Access Bindings](/docs/iam/concepts/access-control/#access-bindings)."""

    def __init__(
        self,
        *,
        action: global___AccessBindingAction.ValueType = ...,
        access_binding: global___AccessBinding | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access_binding", b"access_binding"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_binding", b"access_binding", "action", b"action"]) -> None: ...

global___AccessBindingDelta = AccessBindingDelta

@typing.final
class AccessBindingsOperationResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_DELTAS_FIELD_NUMBER: builtins.int
    @property
    def effective_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AccessBindingDelta]:
        """Result access binding deltas."""

    def __init__(
        self,
        *,
        effective_deltas: collections.abc.Iterable[global___AccessBindingDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["effective_deltas", b"effective_deltas"]) -> None: ...

global___AccessBindingsOperationResult = AccessBindingsOperationResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.speechsense.v1.analysis.statistics_common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class UtteranceStatistics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEAKER_TAG_FIELD_NUMBER: builtins.int
    SPEECH_BOUNDARIES_FIELD_NUMBER: builtins.int
    TOTAL_SPEECH_MS_FIELD_NUMBER: builtins.int
    SPEECH_RATIO_FIELD_NUMBER: builtins.int
    TOTAL_SILENCE_MS_FIELD_NUMBER: builtins.int
    SILENCE_RATIO_FIELD_NUMBER: builtins.int
    WORDS_COUNT_FIELD_NUMBER: builtins.int
    LETTERS_COUNT_FIELD_NUMBER: builtins.int
    WORDS_PER_SECOND_FIELD_NUMBER: builtins.int
    LETTERS_PER_SECOND_FIELD_NUMBER: builtins.int
    speaker_tag: builtins.str
    total_speech_ms: builtins.int
    """Total speech duration"""
    speech_ratio: builtins.float
    """Speech ratio within audio segment"""
    total_silence_ms: builtins.int
    """Total silence duration"""
    silence_ratio: builtins.float
    """Silence ratio within audio segment"""
    words_count: builtins.int
    """Number of words in recognized speech"""
    letters_count: builtins.int
    """Number of letters in recognized speech"""
    @property
    def speech_boundaries(self) -> yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.AudioSegmentBoundaries:
        """Audio segment boundaries"""

    @property
    def words_per_second(self) -> yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.DescriptiveStatistics:
        """Descriptive statistics for words per second distribution"""

    @property
    def letters_per_second(self) -> yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.DescriptiveStatistics:
        """Descriptive statistics for letters per second distribution"""

    def __init__(
        self,
        *,
        speaker_tag: builtins.str = ...,
        speech_boundaries: yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.AudioSegmentBoundaries | None = ...,
        total_speech_ms: builtins.int = ...,
        speech_ratio: builtins.float = ...,
        total_silence_ms: builtins.int = ...,
        silence_ratio: builtins.float = ...,
        words_count: builtins.int = ...,
        letters_count: builtins.int = ...,
        words_per_second: yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.DescriptiveStatistics | None = ...,
        letters_per_second: yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.DescriptiveStatistics | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["letters_per_second", b"letters_per_second", "speech_boundaries", b"speech_boundaries", "words_per_second", b"words_per_second"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["letters_count", b"letters_count", "letters_per_second", b"letters_per_second", "silence_ratio", b"silence_ratio", "speaker_tag", b"speaker_tag", "speech_boundaries", b"speech_boundaries", "speech_ratio", b"speech_ratio", "total_silence_ms", b"total_silence_ms", "total_speech_ms", b"total_speech_ms", "words_count", b"words_count", "words_per_second", b"words_per_second"]) -> None: ...

global___UtteranceStatistics = UtteranceStatistics



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/api/operation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n yandex/cloud/api/operation.proto\x12\x10yandex.cloud.api\x1a google/protobuf/descriptor.proto\"/\n\tOperation\x12\x10\n\x08metadata\x18\x01 \x01(\t\x12\x10\n\x08response\x18\x02 \x01(\t:P\n\toperation\x12\x1e.google.protobuf.MethodOptions\x18\xa6\xaa\x05 \x01(\x0b\x32\x1b.yandex.cloud.api.OperationB:Z8github.com/yandex-cloud/go-genproto/yandex/cloud/api;apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.api.operation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z8github.com/yandex-cloud/go-genproto/yandex/cloud/api;api'
  _globals['_OPERATION']._serialized_start=88
  _globals['_OPERATION']._serialized_end=135
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/airflow/v1/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$yandex/cloud/airflow/v1/common.proto\x12\x17yandex.cloud.airflow.v1\"-\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x03 \x01(\tJ\x04\x08\x01\x10\x03*?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\x42\x62\n\x1byandex.cloud.api.airflow.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/airflow/v1;airflowb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.airflow.v1.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.airflow.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/airflow/v1;airflow'
  _globals['_HEALTH']._serialized_start=112
  _globals['_HEALTH']._serialized_end=175
  _globals['_RESOURCES']._serialized_start=65
  _globals['_RESOURCES']._serialized_end=110
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Customer(google.protobuf.message.Message):
    """A Customer resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the customer."""
    billing_account_id: builtins.str
    """ID of the [yandex.cloud.billing.v1.BillingAccount] assigned to the customer."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        billing_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["billing_account_id", b"billing_account_id", "id", b"id"]) -> None: ...

global___Customer = Customer

@typing.final
class CustomerPerson(google.protobuf.message.Message):
    """Person of the customer. Contains legal information."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    LONGNAME_FIELD_NUMBER: builtins.int
    PHONE_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    POST_CODE_FIELD_NUMBER: builtins.int
    POST_ADDRESS_FIELD_NUMBER: builtins.int
    LEGAL_ADDRESS_FIELD_NUMBER: builtins.int
    TIN_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Optional. Name of the person.

    String length is not limited.
    """
    longname: builtins.str
    """Optional. Long name of the person.

    String length is not limited.
    """
    phone: builtins.str
    """Optional. Phone of the person.

    Must be a valid telephone number or a valid [phoneword](https://en.m.wikipedia.org/wiki/Phoneword).
    """
    email: builtins.str
    """Optional. Email of the person.

    Must be a valid [email address](https://en.wikipedia.org/wiki/Email_address).
    """
    post_code: builtins.str
    """Optional. Post code of the person.

    String length is not limited.
    """
    post_address: builtins.str
    """Optional. Post address of the person.

    String length is not limited.
    """
    legal_address: builtins.str
    """Optional. Legal address of the person.

    String length is not limited.
    """
    tin: builtins.str
    """Optional. Tax identification number of the person.

    String length is not limited.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        longname: builtins.str = ...,
        phone: builtins.str = ...,
        email: builtins.str = ...,
        post_code: builtins.str = ...,
        post_address: builtins.str = ...,
        legal_address: builtins.str = ...,
        tin: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["email", b"email", "legal_address", b"legal_address", "longname", b"longname", "name", b"name", "phone", b"phone", "post_address", b"post_address", "post_code", b"post_code", "tin", b"tin"]) -> None: ...

global___CustomerPerson = CustomerPerson



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.iam.v1 import service_control_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__pb2
from yandex.cloud.iam.v1 import service_control_service_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class ServiceControlServiceStub(object):
    """A set of methods for managing Service resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.iam.v1.ServiceControlService/Get',
                request_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2.GetServiceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__pb2.Service.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.iam.v1.ServiceControlService/List',
                request_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2.ListServicesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2.ListServicesResponse.FromString,
                )
        self.Enable = channel.unary_unary(
                '/yandex.cloud.iam.v1.ServiceControlService/Enable',
                request_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2.EnableServiceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Disable = channel.unary_unary(
                '/yandex.cloud.iam.v1.ServiceControlService/Disable',
                request_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2.DisableServiceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ResolveAgent = channel.unary_unary(
                '/yandex.cloud.iam.v1.ServiceControlService/ResolveAgent',
                request_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2.ResolveServiceAgentRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__pb2.ServiceAgent.FromString,
                )


class ServiceControlServiceServicer(object):
    """A set of methods for managing Service resources.
    """

    def Get(self, request, context):
        """Returns the Service information in the specified resource container.

        To get the list of available Services, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of Service in the specified resource container.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Enable(self, request, context):
        """Enable a service in the specified resource container.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Disable(self, request, context):
        """Disable a service in the specified resource container.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResolveAgent(self, request, context):
        """Resolve agent service account for the service in the specified resource container.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ServiceControlServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2.GetServiceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__pb2.Service.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2.ListServicesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2.ListServicesResponse.SerializeToString,
            ),
            'Enable': grpc.unary_unary_rpc_method_handler(
                    servicer.Enable,
                    request_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2.EnableServiceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Disable': grpc.unary_unary_rpc_method_handler(
                    servicer.Disable,
                    request_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2.DisableServiceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ResolveAgent': grpc.unary_unary_rpc_method_handler(
                    servicer.ResolveAgent,
                    request_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2.ResolveServiceAgentRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__pb2.ServiceAgent.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.iam.v1.ServiceControlService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ServiceControlService(object):
    """A set of methods for managing Service resources.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iam.v1.ServiceControlService/Get',
            yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2.GetServiceRequest.SerializeToString,
            yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__pb2.Service.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iam.v1.ServiceControlService/List',
            yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2.ListServicesRequest.SerializeToString,
            yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2.ListServicesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Enable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iam.v1.ServiceControlService/Enable',
            yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2.EnableServiceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Disable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iam.v1.ServiceControlService/Disable',
            yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2.DisableServiceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResolveAgent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iam.v1.ServiceControlService/ResolveAgent',
            yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__service__pb2.ResolveServiceAgentRequest.SerializeToString,
            yandex_dot_cloud_dot_iam_dot_v1_dot_service__control__pb2.ServiceAgent.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TitleWidget(google.protobuf.message.Message):
    """Title widget."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _TitleSize:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TitleSizeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TitleWidget._TitleSize.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TITLE_SIZE_UNSPECIFIED: TitleWidget._TitleSize.ValueType  # 0
        TITLE_SIZE_XS: TitleWidget._TitleSize.ValueType  # 1
        """Extra small size."""
        TITLE_SIZE_S: TitleWidget._TitleSize.ValueType  # 2
        """Small size."""
        TITLE_SIZE_M: TitleWidget._TitleSize.ValueType  # 3
        """Middle size."""
        TITLE_SIZE_L: TitleWidget._TitleSize.ValueType  # 4
        """Large size."""

    class TitleSize(_TitleSize, metaclass=_TitleSizeEnumTypeWrapper):
        """Title size."""

    TITLE_SIZE_UNSPECIFIED: TitleWidget.TitleSize.ValueType  # 0
    TITLE_SIZE_XS: TitleWidget.TitleSize.ValueType  # 1
    """Extra small size."""
    TITLE_SIZE_S: TitleWidget.TitleSize.ValueType  # 2
    """Small size."""
    TITLE_SIZE_M: TitleWidget.TitleSize.ValueType  # 3
    """Middle size."""
    TITLE_SIZE_L: TitleWidget.TitleSize.ValueType  # 4
    """Large size."""

    TEXT_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Title text."""
    size: global___TitleWidget.TitleSize.ValueType
    """Title size."""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        size: global___TitleWidget.TitleSize.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["size", b"size", "text", b"text"]) -> None: ...

global___TitleWidget = TitleWidget



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/instance.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.compute.v1 import hardware_generation_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_hardware__generation__pb2
from yandex.cloud.compute.v1 import maintenance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_maintenance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/compute/v1/instance.proto\x12\x17yandex.cloud.compute.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31yandex/cloud/compute/v1/hardware_generation.proto\x1a)yandex/cloud/compute/v1/maintenance.proto\"\xae\r\n\x08Instance\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12=\n\x06labels\x18\x06 \x03(\x0b\x32-.yandex.cloud.compute.v1.Instance.LabelsEntry\x12\x0f\n\x07zone_id\x18\x07 \x01(\t\x12\x13\n\x0bplatform_id\x18\x08 \x01(\t\x12\x35\n\tresources\x18\t \x01(\x0b\x32\".yandex.cloud.compute.v1.Resources\x12\x38\n\x06status\x18\n \x01(\x0e\x32(.yandex.cloud.compute.v1.Instance.Status\x12\x41\n\x08metadata\x18\x0b \x03(\x0b\x32/.yandex.cloud.compute.v1.Instance.MetadataEntry\x12\x42\n\x10metadata_options\x18\x17 \x01(\x0b\x32(.yandex.cloud.compute.v1.MetadataOptions\x12\x38\n\tboot_disk\x18\x0c \x01(\x0b\x32%.yandex.cloud.compute.v1.AttachedDisk\x12>\n\x0fsecondary_disks\x18\r \x03(\x0b\x32%.yandex.cloud.compute.v1.AttachedDisk\x12?\n\x0blocal_disks\x18\x16 \x03(\x0b\x32*.yandex.cloud.compute.v1.AttachedLocalDisk\x12@\n\x0b\x66ilesystems\x18\x15 \x03(\x0b\x32+.yandex.cloud.compute.v1.AttachedFilesystem\x12\x45\n\x12network_interfaces\x18\x0e \x03(\x0b\x32).yandex.cloud.compute.v1.NetworkInterface\x12I\n\x14serial_port_settings\x18\x18 \x01(\x0b\x32+.yandex.cloud.compute.v1.SerialPortSettings\x12:\n\x0cgpu_settings\x18\x1a \x01(\x0b\x32$.yandex.cloud.compute.v1.GpuSettings\x12\x0c\n\x04\x66qdn\x18\x10 \x01(\t\x12\x44\n\x11scheduling_policy\x18\x11 \x01(\x0b\x32).yandex.cloud.compute.v1.SchedulingPolicy\x12\x1a\n\x12service_account_id\x18\x12 \x01(\t\x12\x42\n\x10network_settings\x18\x13 \x01(\x0b\x32(.yandex.cloud.compute.v1.NetworkSettings\x12\x42\n\x10placement_policy\x18\x14 \x01(\x0b\x32(.yandex.cloud.compute.v1.PlacementPolicy\x12\x15\n\rhost_group_id\x18\x1b \x01(\t\x12\x0f\n\x07host_id\x18\x1c \x01(\t\x12\x46\n\x12maintenance_policy\x18\x1d \x01(\x0e\x32*.yandex.cloud.compute.v1.MaintenancePolicy\x12;\n\x18maintenance_grace_period\x18\x1e \x01(\x0b\x32\x19.google.protobuf.Duration\x12H\n\x13hardware_generation\x18\x1f \x01(\x0b\x32+.yandex.cloud.compute.v1.HardwareGeneration\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xac\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0c\n\x08STOPPING\x10\x03\x12\x0b\n\x07STOPPED\x10\x04\x12\x0c\n\x08STARTING\x10\x05\x12\x0e\n\nRESTARTING\x10\x06\x12\x0c\n\x08UPDATING\x10\x07\x12\t\n\x05\x45RROR\x10\x08\x12\x0b\n\x07\x43RASHED\x10\t\x12\x0c\n\x08\x44\x45LETING\x10\nJ\x04\x08\x0f\x10\x10J\x04\x08\x19\x10\x1a\"O\n\tResources\x12\x0e\n\x06memory\x18\x01 \x01(\x03\x12\r\n\x05\x63ores\x18\x02 \x01(\x03\x12\x15\n\rcore_fraction\x18\x03 \x01(\x03\x12\x0c\n\x04gpus\x18\x04 \x01(\x03\"\xc0\x01\n\x0c\x41ttachedDisk\x12\x38\n\x04mode\x18\x01 \x01(\x0e\x32*.yandex.cloud.compute.v1.AttachedDisk.Mode\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x13\n\x0b\x61uto_delete\x18\x03 \x01(\x08\x12\x0f\n\x07\x64isk_id\x18\x04 \x01(\t\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02\"6\n\x11\x41ttachedLocalDisk\x12\x0c\n\x04size\x18\x01 \x01(\x03\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\"\xbd\x01\n\x12\x41ttachedFilesystem\x12>\n\x04mode\x18\x01 \x01(\x0e\x32\x30.yandex.cloud.compute.v1.AttachedFilesystem.Mode\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x15\n\rfilesystem_id\x18\x03 \x01(\t\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02\"\xef\x01\n\x10NetworkInterface\x12\r\n\x05index\x18\x01 \x01(\t\x12\x13\n\x0bmac_address\x18\x02 \x01(\t\x12\x11\n\tsubnet_id\x18\x03 \x01(\t\x12\x43\n\x12primary_v4_address\x18\x04 \x01(\x0b\x32\'.yandex.cloud.compute.v1.PrimaryAddress\x12\x43\n\x12primary_v6_address\x18\x05 \x01(\x0b\x32\'.yandex.cloud.compute.v1.PrimaryAddress\x12\x1a\n\x12security_group_ids\x18\x06 \x03(\t\"\x98\x01\n\x0ePrimaryAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12<\n\x0eone_to_one_nat\x18\x02 \x01(\x0b\x32$.yandex.cloud.compute.v1.OneToOneNat\x12\x37\n\x0b\x64ns_records\x18\x03 \x03(\x0b\x32\".yandex.cloud.compute.v1.DnsRecord\"\x8f\x01\n\x0bOneToOneNat\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x36\n\nip_version\x18\x02 \x01(\x0e\x32\".yandex.cloud.compute.v1.IpVersion\x12\x37\n\x0b\x64ns_records\x18\x03 \x03(\x0b\x32\".yandex.cloud.compute.v1.DnsRecord\"H\n\tDnsRecord\x12\x0c\n\x04\x66qdn\x18\x01 \x01(\t\x12\x13\n\x0b\x64ns_zone_id\x18\x02 \x01(\t\x12\x0b\n\x03ttl\x18\x03 \x01(\x03\x12\x0b\n\x03ptr\x18\x04 \x01(\x08\"\'\n\x10SchedulingPolicy\x12\x13\n\x0bpreemptible\x18\x01 \x01(\x08\"\xae\x01\n\x0fNetworkSettings\x12;\n\x04type\x18\x01 \x01(\x0e\x32-.yandex.cloud.compute.v1.NetworkSettings.Type\"^\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\x12\x18\n\x14SOFTWARE_ACCELERATED\x10\x02\x12\x18\n\x14HARDWARE_ACCELERATED\x10\x03\"%\n\x0bGpuSettings\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\"\xe4\x02\n\x0fPlacementPolicy\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\x12V\n\x13host_affinity_rules\x18\x02 \x03(\x0b\x32\x39.yandex.cloud.compute.v1.PlacementPolicy.HostAffinityRule\x12!\n\x19placement_group_partition\x18\x03 \x01(\x03\x1a\xb9\x01\n\x10HostAffinityRule\x12\x0b\n\x03key\x18\x01 \x01(\t\x12N\n\x02op\x18\x02 \x01(\x0e\x32\x42.yandex.cloud.compute.v1.PlacementPolicy.HostAffinityRule.Operator\x12\x0e\n\x06values\x18\x03 \x03(\t\"8\n\x08Operator\x12\x18\n\x14OPERATOR_UNSPECIFIED\x10\x00\x12\x06\n\x02IN\x10\x01\x12\n\n\x06NOT_IN\x10\x02\"\xa1\x02\n\x0fMetadataOptions\x12\x42\n\x11gce_http_endpoint\x18\x01 \x01(\x0e\x32\'.yandex.cloud.compute.v1.MetadataOption\x12\x45\n\x14\x61ws_v1_http_endpoint\x18\x02 \x01(\x0e\x32\'.yandex.cloud.compute.v1.MetadataOption\x12?\n\x0egce_http_token\x18\x03 \x01(\x0e\x32\'.yandex.cloud.compute.v1.MetadataOption\x12\x42\n\x11\x61ws_v1_http_token\x18\x04 \x01(\x0e\x32\'.yandex.cloud.compute.v1.MetadataOption\"\xc9\x01\n\x12SerialPortSettings\x12W\n\x11ssh_authorization\x18\x01 \x01(\x0e\x32<.yandex.cloud.compute.v1.SerialPortSettings.SSHAuthorization\"Z\n\x10SSHAuthorization\x12!\n\x1dSSH_AUTHORIZATION_UNSPECIFIED\x10\x00\x12\x15\n\x11INSTANCE_METADATA\x10\x01\x12\x0c\n\x08OS_LOGIN\x10\x02*;\n\tIpVersion\x12\x1a\n\x16IP_VERSION_UNSPECIFIED\x10\x00\x12\x08\n\x04IPV4\x10\x01\x12\x08\n\x04IPV6\x10\x02*L\n\x0eMetadataOption\x12\x1f\n\x1bMETADATA_OPTION_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\x42\x62\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.instance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _INSTANCE_LABELSENTRY._options = None
  _INSTANCE_LABELSENTRY._serialized_options = b'8\001'
  _INSTANCE_METADATAENTRY._options = None
  _INSTANCE_METADATAENTRY._serialized_options = b'8\001'
  _globals['_IPVERSION']._serialized_start=4192
  _globals['_IPVERSION']._serialized_end=4251
  _globals['_METADATAOPTION']._serialized_start=4253
  _globals['_METADATAOPTION']._serialized_end=4329
  _globals['_INSTANCE']._serialized_start=227
  _globals['_INSTANCE']._serialized_end=1937
  _globals['_INSTANCE_LABELSENTRY']._serialized_start=1656
  _globals['_INSTANCE_LABELSENTRY']._serialized_end=1701
  _globals['_INSTANCE_METADATAENTRY']._serialized_start=1703
  _globals['_INSTANCE_METADATAENTRY']._serialized_end=1750
  _globals['_INSTANCE_STATUS']._serialized_start=1753
  _globals['_INSTANCE_STATUS']._serialized_end=1925
  _globals['_RESOURCES']._serialized_start=1939
  _globals['_RESOURCES']._serialized_end=2018
  _globals['_ATTACHEDDISK']._serialized_start=2021
  _globals['_ATTACHEDDISK']._serialized_end=2213
  _globals['_ATTACHEDDISK_MODE']._serialized_start=2154
  _globals['_ATTACHEDDISK_MODE']._serialized_end=2213
  _globals['_ATTACHEDLOCALDISK']._serialized_start=2215
  _globals['_ATTACHEDLOCALDISK']._serialized_end=2269
  _globals['_ATTACHEDFILESYSTEM']._serialized_start=2272
  _globals['_ATTACHEDFILESYSTEM']._serialized_end=2461
  _globals['_ATTACHEDFILESYSTEM_MODE']._serialized_start=2154
  _globals['_ATTACHEDFILESYSTEM_MODE']._serialized_end=2213
  _globals['_NETWORKINTERFACE']._serialized_start=2464
  _globals['_NETWORKINTERFACE']._serialized_end=2703
  _globals['_PRIMARYADDRESS']._serialized_start=2706
  _globals['_PRIMARYADDRESS']._serialized_end=2858
  _globals['_ONETOONENAT']._serialized_start=2861
  _globals['_ONETOONENAT']._serialized_end=3004
  _globals['_DNSRECORD']._serialized_start=3006
  _globals['_DNSRECORD']._serialized_end=3078
  _globals['_SCHEDULINGPOLICY']._serialized_start=3080
  _globals['_SCHEDULINGPOLICY']._serialized_end=3119
  _globals['_NETWORKSETTINGS']._serialized_start=3122
  _globals['_NETWORKSETTINGS']._serialized_end=3296
  _globals['_NETWORKSETTINGS_TYPE']._serialized_start=3202
  _globals['_NETWORKSETTINGS_TYPE']._serialized_end=3296
  _globals['_GPUSETTINGS']._serialized_start=3298
  _globals['_GPUSETTINGS']._serialized_end=3335
  _globals['_PLACEMENTPOLICY']._serialized_start=3338
  _globals['_PLACEMENTPOLICY']._serialized_end=3694
  _globals['_PLACEMENTPOLICY_HOSTAFFINITYRULE']._serialized_start=3509
  _globals['_PLACEMENTPOLICY_HOSTAFFINITYRULE']._serialized_end=3694
  _globals['_PLACEMENTPOLICY_HOSTAFFINITYRULE_OPERATOR']._serialized_start=3638
  _globals['_PLACEMENTPOLICY_HOSTAFFINITYRULE_OPERATOR']._serialized_end=3694
  _globals['_METADATAOPTIONS']._serialized_start=3697
  _globals['_METADATAOPTIONS']._serialized_end=3986
  _globals['_SERIALPORTSETTINGS']._serialized_start=3989
  _globals['_SERIALPORTSETTINGS']._serialized_end=4190
  _globals['_SERIALPORTSETTINGS_SSHAUTHORIZATION']._serialized_start=4100
  _globals['_SERIALPORTSETTINGS_SSHAUTHORIZATION']._serialized_end=4190
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.apploadbalancer.v1.http_router_pb2
import yandex.cloud.apploadbalancer.v1.virtual_host_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetHttpRouterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router to return.

    To get the HTTP router ID, make a [HttpRouterService.List] request.
    """
    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["http_router_id", b"http_router_id"]) -> None: ...

global___GetHttpRouterRequest = GetHttpRouterRequest

@typing.final
class ListHttpRoutersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list HTTP routers in.

    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListHttpRoutersResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListHttpRoutersResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters HTTP routers listed in the response.

    The expression must specify:
    1. The field name. Currently you can use filtering only on [HttpRouter.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-http-router`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListHttpRoutersRequest = ListHttpRoutersRequest

@typing.final
class ListHttpRoutersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListHttpRoutersRequest.page_size], use `next_page_token` as the value
    for the [ListHttpRoutersRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def http_routers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.http_router_pb2.HttpRouter]:
        """List of HTTP routers in the specified folder."""

    def __init__(
        self,
        *,
        http_routers: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.http_router_pb2.HttpRouter] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["http_routers", b"http_routers", "next_page_token", b"next_page_token"]) -> None: ...

global___ListHttpRoutersResponse = ListHttpRoutersResponse

@typing.final
class DeleteHttpRouterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router to delete.

    To get the HTTP router ID, make a [HttpRouterService.List] request.
    """
    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["http_router_id", b"http_router_id"]) -> None: ...

global___DeleteHttpRouterRequest = DeleteHttpRouterRequest

@typing.final
class DeleteHttpRouterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router that is being deleted."""
    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["http_router_id", b"http_router_id"]) -> None: ...

global___DeleteHttpRouterMetadata = DeleteHttpRouterMetadata

@typing.final
class UpdateHttpRouterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    VIRTUAL_HOSTS_FIELD_NUMBER: builtins.int
    ROUTE_OPTIONS_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router to update.

    To get the HTTP router ID, make a [HttpRouterService.List] request.
    """
    name: builtins.str
    """New name for the HTTP router.
    The name must be unique within the folder.
    """
    description: builtins.str
    """New description of the HTTP router."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the HTTP router should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """HTTP router labels as `key:value` pairs.
        For details about the concept, see [documentation](/docs/overview/concepts/services#labels).

        Existing set of labels is completely replaced by the provided set, so if you just want
        to add or remove a label:
        1. Get the current set of labels with a [HttpRouterService.Get] request.
        2. Add or remove a label in this set.
        3. Send the new set in this field.
        """

    @property
    def virtual_hosts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.VirtualHost]:
        """New virtual hosts that combine routes inside the router.
        For details about the concept, see [documentation](/docs/application-load-balancer/concepts/http-router#virtual-host).

        Only one virtual host with no authority (default match) can be specified.

        Existing list of virtual hosts is completely replaced by the specified list, so if you just want to add or remove
        a virtual host, make a [VirtualHostService.Create] request or a [VirtualHostService.Delete] request.
        """

    @property
    def route_options(self) -> yandex.cloud.apploadbalancer.v1.virtual_host_pb2.RouteOptions:
        """New route options for the HTTP router."""

    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        virtual_hosts: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.VirtualHost] | None = ...,
        route_options: yandex.cloud.apploadbalancer.v1.virtual_host_pb2.RouteOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["route_options", b"route_options", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "http_router_id", b"http_router_id", "labels", b"labels", "name", b"name", "route_options", b"route_options", "update_mask", b"update_mask", "virtual_hosts", b"virtual_hosts"]) -> None: ...

global___UpdateHttpRouterRequest = UpdateHttpRouterRequest

@typing.final
class UpdateHttpRouterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router that is being updated."""
    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["http_router_id", b"http_router_id"]) -> None: ...

global___UpdateHttpRouterMetadata = UpdateHttpRouterMetadata

@typing.final
class CreateHttpRouterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    VIRTUAL_HOSTS_FIELD_NUMBER: builtins.int
    ROUTE_OPTIONS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create an HTTP router in.

    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the HTTP router.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the HTTP router."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """HTTP router labels as `key:value` pairs.
        For details about the concept, see [documentation](/docs/overview/concepts/services#labels).
        """

    @property
    def virtual_hosts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.VirtualHost]:
        """Virtual hosts that combine routes inside the router.
        For details about the concept, see [documentation](/docs/application-load-balancer/concepts/http-router#virtual-host).

        Only one virtual host with no authority (default match) can be specified.
        """

    @property
    def route_options(self) -> yandex.cloud.apploadbalancer.v1.virtual_host_pb2.RouteOptions:
        """Route options for the HTTP router."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        virtual_hosts: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.VirtualHost] | None = ...,
        route_options: yandex.cloud.apploadbalancer.v1.virtual_host_pb2.RouteOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["route_options", b"route_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "route_options", b"route_options", "virtual_hosts", b"virtual_hosts"]) -> None: ...

global___CreateHttpRouterRequest = CreateHttpRouterRequest

@typing.final
class CreateHttpRouterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router that is being created."""
    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["http_router_id", b"http_router_id"]) -> None: ...

global___CreateHttpRouterMetadata = CreateHttpRouterMetadata

@typing.final
class ListHttpRouterOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router to get operations for.

    To get the HTTP router ID, use a [HttpRouterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than [page_size], the service returns a [ListHttpRouterOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListHttpRouterOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["http_router_id", b"http_router_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListHttpRouterOperationsRequest = ListHttpRouterOperationsRequest

@typing.final
class ListHttpRouterOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListHttpRouterOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListHttpRouterOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified HTTP router."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListHttpRouterOperationsResponse = ListHttpRouterOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Extension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    ACTIVE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the extension."""
    id: builtins.str
    """Unique ID of the extension."""
    cluster_id: builtins.str
    """ID of the Elasticsearch cluster the extension belongs to."""
    version: builtins.int
    """Version of the extension."""
    active: builtins.bool
    """The flag shows whether the extension is active."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        id: builtins.str = ...,
        cluster_id: builtins.str = ...,
        version: builtins.int = ...,
        active: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["active", b"active", "cluster_id", b"cluster_id", "id", b"id", "name", b"name", "version", b"version"]) -> None: ...

global___Extension = Extension

@typing.final
class ExtensionSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the extension."""
    uri: builtins.str
    """URI of the zip archive to create the new extension from. Currently only supports links that are stored in Object Storage."""
    disabled: builtins.bool
    """The flag shows whether to create the extension in disabled state."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        uri: builtins.str = ...,
        disabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disabled", b"disabled", "name", b"name", "uri", b"uri"]) -> None: ...

global___ExtensionSpec = ExtensionSpec



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datasphere/v1/app_token_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/datasphere/v1/app_token_service.proto\x12\x1ayandex.cloud.datasphere.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\"(\n\x17\x41ppTokenValidateRequest\x12\r\n\x05token\x18\x01 \x01(\t2\x9e\x01\n\x0f\x41ppTokenService\x12\x8a\x01\n\x08Validate\x12\x33.yandex.cloud.datasphere.v1.AppTokenValidateRequest\x1a\x16.google.protobuf.Empty\"1\x82\xd3\xe4\x93\x02+\")/datasphere/v1/appTokens/{token}:validateBk\n\x1eyandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v1.app_token_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036yandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphere'
  _APPTOKENSERVICE.methods_by_name['Validate']._options = None
  _APPTOKENSERVICE.methods_by_name['Validate']._serialized_options = b'\202\323\344\223\002+\")/datasphere/v1/appTokens/{token}:validate'
  _globals['_APPTOKENVALIDATEREQUEST']._serialized_start=141
  _globals['_APPTOKENVALIDATEREQUEST']._serialized_end=181
  _globals['_APPTOKENSERVICE']._serialized_start=184
  _globals['_APPTOKENSERVICE']._serialized_end=342
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GenerationOptions(google.protobuf.message.Message):
    """Defines the options for text generation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARTIAL_RESULTS_FIELD_NUMBER: builtins.int
    TEMPERATURE_FIELD_NUMBER: builtins.int
    MAX_TOKENS_FIELD_NUMBER: builtins.int
    partial_results: builtins.bool
    """Enables streaming of partially generated text."""
    @property
    def temperature(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """Affects creativity and randomness of responses. Should be a double number between 0 (inclusive) and 1 (inclusive).
        Lower values produce more straightforward responses, while higher values lead to increased creativity and randomness.
        """

    @property
    def max_tokens(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum limit on the total number of tokens used for both the input prompt and the generated response.
        Must be greater than zero and not exceed 7400 tokens.
        """

    def __init__(
        self,
        *,
        partial_results: builtins.bool = ...,
        temperature: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        max_tokens: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_tokens", b"max_tokens", "temperature", b"temperature"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["max_tokens", b"max_tokens", "partial_results", b"partial_results", "temperature", b"temperature"]) -> None: ...

global___GenerationOptions = GenerationOptions

@typing.final
class Alternative(google.protobuf.message.Message):
    """Represents an alternative generated response, including its score and token count."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    NUM_TOKENS_FIELD_NUMBER: builtins.int
    text: builtins.str
    """The generated text response."""
    score: builtins.float
    """The score or confidence of the generated text."""
    num_tokens: builtins.int
    """The number of tokens in the generated response."""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        score: builtins.float = ...,
        num_tokens: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["num_tokens", b"num_tokens", "score", b"score", "text", b"text"]) -> None: ...

global___Alternative = Alternative

@typing.final
class Message(google.protobuf.message.Message):
    """Represents a message within a chat."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    role: builtins.str
    """Identifies the sender of the message."""
    text: builtins.str
    """The text content of the message."""
    def __init__(
        self,
        *,
        role: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["role", b"role", "text", b"text"]) -> None: ...

global___Message = Message

@typing.final
class Token(google.protobuf.message.Message):
    """Represents a token, the basic unit of text, used by the LLM."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    SPECIAL_FIELD_NUMBER: builtins.int
    id: builtins.int
    """An internal token identifier."""
    text: builtins.str
    """The textual representation of the token."""
    special: builtins.bool
    """Indicates whether the token is special or not. Special tokens define the model's behavior and are not visible to users."""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        text: builtins.str = ...,
        special: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "special", b"special", "text", b"text"]) -> None: ...

global___Token = Token



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.lockbox.v1.secret_pb2
import yandex.cloud.lockbox.v1.secret_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SecretServiceStub:
    """A set of methods for managing secrets."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.GetSecretRequest,
        yandex.cloud.lockbox.v1.secret_pb2.Secret,
    ]
    """Returns the specified secret.

    To get the list of all available secrets, make a [List] request.
    Use [PayloadService.Get] to get the payload (confidential data themselves) of the secret.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.ListSecretsRequest,
        yandex.cloud.lockbox.v1.secret_service_pb2.ListSecretsResponse,
    ]
    """Retrieves the list of secrets in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.CreateSecretRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a secret in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.UpdateSecretRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified secret."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.DeleteSecretRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified secret."""

    Activate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.ActivateSecretRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Activates the specified secret."""

    Deactivate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.DeactivateSecretRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deactivates the specified secret."""

    ListVersions: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.ListVersionsRequest,
        yandex.cloud.lockbox.v1.secret_service_pb2.ListVersionsResponse,
    ]
    """Retrieves the list of versions of the specified secret."""

    AddVersion: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.AddVersionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds new version based on a previous one."""

    ScheduleVersionDestruction: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.ScheduleVersionDestructionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Schedules the specified version for destruction.

    Scheduled destruction can be cancelled with the [SecretService.CancelVersionDestruction] method.
    """

    CancelVersionDestruction: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.CancelVersionDestructionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Cancels previously scheduled version destruction, if the version hasn't been destroyed yet."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.ListSecretOperationsRequest,
        yandex.cloud.lockbox.v1.secret_service_pb2.ListSecretOperationsResponse,
    ]
    """Lists operations for the specified secret."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified secret."""

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the secret."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the secret."""

class SecretServiceAsyncStub:
    """A set of methods for managing secrets."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.GetSecretRequest,
        yandex.cloud.lockbox.v1.secret_pb2.Secret,
    ]
    """Returns the specified secret.

    To get the list of all available secrets, make a [List] request.
    Use [PayloadService.Get] to get the payload (confidential data themselves) of the secret.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.ListSecretsRequest,
        yandex.cloud.lockbox.v1.secret_service_pb2.ListSecretsResponse,
    ]
    """Retrieves the list of secrets in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.CreateSecretRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a secret in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.UpdateSecretRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified secret."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.DeleteSecretRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified secret."""

    Activate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.ActivateSecretRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Activates the specified secret."""

    Deactivate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.DeactivateSecretRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deactivates the specified secret."""

    ListVersions: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.ListVersionsRequest,
        yandex.cloud.lockbox.v1.secret_service_pb2.ListVersionsResponse,
    ]
    """Retrieves the list of versions of the specified secret."""

    AddVersion: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.AddVersionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds new version based on a previous one."""

    ScheduleVersionDestruction: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.ScheduleVersionDestructionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Schedules the specified version for destruction.

    Scheduled destruction can be cancelled with the [SecretService.CancelVersionDestruction] method.
    """

    CancelVersionDestruction: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.CancelVersionDestructionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Cancels previously scheduled version destruction, if the version hasn't been destroyed yet."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.secret_service_pb2.ListSecretOperationsRequest,
        yandex.cloud.lockbox.v1.secret_service_pb2.ListSecretOperationsResponse,
    ]
    """Lists operations for the specified secret."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified secret."""

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the secret."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the secret."""

class SecretServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing secrets."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.lockbox.v1.secret_service_pb2.GetSecretRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.lockbox.v1.secret_pb2.Secret, collections.abc.Awaitable[yandex.cloud.lockbox.v1.secret_pb2.Secret]]:
        """Returns the specified secret.

        To get the list of all available secrets, make a [List] request.
        Use [PayloadService.Get] to get the payload (confidential data themselves) of the secret.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.lockbox.v1.secret_service_pb2.ListSecretsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.lockbox.v1.secret_service_pb2.ListSecretsResponse, collections.abc.Awaitable[yandex.cloud.lockbox.v1.secret_service_pb2.ListSecretsResponse]]:
        """Retrieves the list of secrets in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.lockbox.v1.secret_service_pb2.CreateSecretRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a secret in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.lockbox.v1.secret_service_pb2.UpdateSecretRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified secret."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.lockbox.v1.secret_service_pb2.DeleteSecretRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified secret."""

    @abc.abstractmethod
    def Activate(
        self,
        request: yandex.cloud.lockbox.v1.secret_service_pb2.ActivateSecretRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Activates the specified secret."""

    @abc.abstractmethod
    def Deactivate(
        self,
        request: yandex.cloud.lockbox.v1.secret_service_pb2.DeactivateSecretRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deactivates the specified secret."""

    @abc.abstractmethod
    def ListVersions(
        self,
        request: yandex.cloud.lockbox.v1.secret_service_pb2.ListVersionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.lockbox.v1.secret_service_pb2.ListVersionsResponse, collections.abc.Awaitable[yandex.cloud.lockbox.v1.secret_service_pb2.ListVersionsResponse]]:
        """Retrieves the list of versions of the specified secret."""

    @abc.abstractmethod
    def AddVersion(
        self,
        request: yandex.cloud.lockbox.v1.secret_service_pb2.AddVersionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds new version based on a previous one."""

    @abc.abstractmethod
    def ScheduleVersionDestruction(
        self,
        request: yandex.cloud.lockbox.v1.secret_service_pb2.ScheduleVersionDestructionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Schedules the specified version for destruction.

        Scheduled destruction can be cancelled with the [SecretService.CancelVersionDestruction] method.
        """

    @abc.abstractmethod
    def CancelVersionDestruction(
        self,
        request: yandex.cloud.lockbox.v1.secret_service_pb2.CancelVersionDestructionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Cancels previously scheduled version destruction, if the version hasn't been destroyed yet."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.lockbox.v1.secret_service_pb2.ListSecretOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.lockbox.v1.secret_service_pb2.ListSecretOperationsResponse, collections.abc.Awaitable[yandex.cloud.lockbox.v1.secret_service_pb2.ListSecretOperationsResponse]]:
        """Lists operations for the specified secret."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """Lists existing access bindings for the specified secret."""

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the secret."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the secret."""

def add_SecretServiceServicer_to_server(servicer: SecretServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
